
/*
libfawk - A function-only AWK dialect - compacted, single-source-file version
(for a human readable source code please visit the project page)

Copyright (c) 2017..2019 Tibor 'Igor2' Palinkas. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  * 1. Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in the
    documentation and/or other materials provided with the distribution.
  * 3. Neither the name of the copyright holder nor the names of its
    contributors may be used to endorse or promote products derived from this
    software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS AS IS AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Project page: http://repo.hu/projects/libfawk
Source code: svn://repo.hu/libfawk/trunk
Contact the author: http://igor2.repo.hu/contact.html
*/


#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <ctype.h>
#include <math.h>
#include <assert.h>
#ifndef fawk_malloc
#define fawk_malloc(ctx,size) malloc(size)
#define fawk_calloc(ctx,n,m) calloc(n, m)
#define fawk_realloc(ctx,ptr,size) realloc(ptr, size)
#define fawk_free(ctx,ptr) free(ptr)
#endif
#define PT_NEQ 257
#define PT_GTEQ 258
#define PT_LTEQ 259
#define PT_NIL 260
#define PT_IF 261
#define PT_THEN 262
#define PT_ELSE 263
#define PT_DO 264
#define PT_WHILE 265
#define PT_REPEAT 266
#define PT_UNTIL 267
#define PT_FOR 268
#define PT_DOWN 269
#define PT_TO 270
#define PT_FUNCTION 271
#define PT_BEGIN 272
#define PT_END 273
#define PT_CURRFUNC 274
#define PT_EXIT 275
#define PT_ID 276
#define PT_STRING 277
#define PT_NUM 278
#define PT_OR 279
#define PT_AND 280
#define PT_IN 281
#define PT_NOT 282
#ifdef YYSTYPE
#undef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
extern YYSTYPE fawkpas_lval;
FAWK_API int fawk_parse_fpas(fawk_ctx_t *ctx);
FAWK_API int fawk_lex_fpas(YYSTYPE *lval, fawk_ctx_t *ctx);
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20140715
#define YYEMPTY (-1)
#define yyclearin (yychar = YYEMPTY)
#define yyerrok (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)
#define YYENOMEM (-2)
#define YYEOF 0
#define yyparse fawkpas_parse
#define yylex fawkpas_lex
#define yyerror fawkpas_error
#define yychar fawkpas_char
#define yyval fawkpas_val
#define yylval fawkpas_lval
#define yydebug fawkpas_debug
#define yynerrs fawkpas_nerrs
#define yyerrflag fawkpas_errflag
#define yylhs fawkpas_lhs
#define yylen fawkpas_len
#define yydefred fawkpas_defred
#define yydgoto fawkpas_dgoto
#define yysindex fawkpas_sindex
#define yyrindex fawkpas_rindex
#define yygindex fawkpas_gindex
#define yytable fawkpas_table
#define yycheck fawkpas_check
#define yyname fawkpas_name
#define yyrule fawkpas_rule
#define YYPREFIX "fawkpas_"
#define YYPURE 1
#define extern 
#define fawkpas_parse FAWK_API fawk_parse_fpas
#define fawkpas_error fawk_error
#define fawkpas_lex fawk_lex_fpas
#define YY_DECL_IS_OURS 0
#define YY_DECL int fawk_lex_fpas(YYSTYPE *fawk_lval, fawk_ctx_t *ctx)
#define PUSH_IP() fawk_push_num(ctx, ctx->code.used)
#define CURR_IP() ctx->code.used
#define pas_func_ret() \
 fawkc_addi(ctx, FAWKI_RET); \
 fawkc_addnum(ctx, ctx->compiler.numargs);
#ifdef YYSTYPE
#undef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifdef YYPARSE_PARAM
# ifdef YYPARSE_PARAM_TYPE
#define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
#define YYPARSE_DECL() yyparse(fawk_ctx_t * ctx)
#endif
#ifdef YYLEX_PARAM
# ifdef YYLEX_PARAM_TYPE
#define YYLEX_DECL() yylex(YYSTYPE *yylval, YYLEX_PARAM_TYPE YYLEX_PARAM)
# else
#define YYLEX_DECL() yylex(YYSTYPE *yylval, void * YYLEX_PARAM)
# endif
#define YYLEX yylex(&yylval, YYLEX_PARAM)
#else
#define YYLEX_DECL() yylex(YYSTYPE *yylval, fawk_ctx_t * ctx)
#define YYLEX yylex(&yylval, ctx)
#endif
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(fawk_ctx_t * ctx, const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(ctx, msg)
#endif
extern int YYPARSE_DECL();
#define PT_NEQ 257
#define PT_GTEQ 258
#define PT_LTEQ 259
#define PT_NIL 260
#define PT_IF 261
#define PT_THEN 262
#define PT_ELSE 263
#define PT_DO 264
#define PT_WHILE 265
#define PT_REPEAT 266
#define PT_UNTIL 267
#define PT_FOR 268
#define PT_DOWN 269
#define PT_TO 270
#define PT_FUNCTION 271
#define PT_BEGIN 272
#define PT_END 273
#define PT_CURRFUNC 274
#define PT_EXIT 275
#define PT_ID 276
#define PT_STRING 277
#define PT_NUM 278
#define PT_OR 279
#define PT_AND 280
#define PT_IN 281
#define PT_NOT 282
#define YYERRCODE 256
typedef short YYINT;
static const YYINT fawkpas_lhs[] = { -1,
3, 0, 2, 2, 5, 5, 5, 5, 5, 5, 5, 13, 13, 12, 12, 15, 15, 6, 18, 8, 9, 19, 9, 11, 11, 22, 21, 23, 24, 25, 20, 1, 1, 10, 10, 28, 29, 26, 30, 27, 14, 32, 14, 31, 33, 35, 4, 34, 34, 34, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 39, 16, 38, 38, 38, 38, 38, 40, 41, 40, 42, 36, 43, 37, 45, 7, 44, 44, 44, };
static const YYINT fawkpas_len[] = { 2,
0, 2, 2, 0, 1, 1, 1, 1, 1, 1, 3, 1, 1, 0, 2, 2, 1, 4, 0, 5, 1, 0, 5, 1, 1, 0, 8, 0, 0, 0, 11, 2, 3, 1, 1, 0, 0, 6, 0, 5, 3, 0, 5, 3, 0, 0, 12, 0, 1, 3, 1, 1, 1, 1, 2, 1, 3, 3, 3, 3, 3, 3, 3, 3, 1, 1, 3, 3, 3, 3, 3, 2, 2, 2, 3, 0, 3, 0, 3, 4, 3, 3, 1, 0, 4, 0, 4, 0, 4, 0, 5, 0, 1, 3, };
static const YYINT fawkpas_defred[] = { 1,
0, 0, 0, 2, 0, 45, 3, 0, 0, 49, 0, 0, 0, 46, 50, 0, 14, 0, 53, 0, 36, 39, 0, 14, 0, 0, 0, 76, 52, 51, 0, 0, 0, 0, 0, 0, 5, 0, 7, 8, 9, 10, 17, 15, 0, 0, 24, 25, 34, 35, 0, 65, 66, 56, 54, 0, 0, 14, 0, 0, 0, 47, 0, 22, 78, 0, 0, 0, 0, 55, 16, 0, 0, 0, 0, 86, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 90, 12, 0, 13, 44, 0, 0, 0, 0, 11, 19, 0, 0, 57, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 42, 41, 37, 0, 28, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23,
 79, 0, 0, 81, 82, 0, 91, 43, 38, 0, 26, 84, 80, 94, 0, 0, 0, 0, 0, 30, 27, 0, 0, 0, 0, 0, 0, 31, };
static const YYINT fawkpas_dgoto[] = { 1,
160, 4, 2, 5, 36, 37, 54, 39, 40, 41, 42, 18, 90, 43, 44, 55, 46, 125, 99, 47, 48, 156, 137, 155, 165, 49, 50, 57, 135, 58, 51, 134, 8, 11, 16, 52, 53, 100, 65, 143, 157, 106, 107, 133, 118, };
static const YYINT fawkpas_sindex[] = { 0,
0, -258, -261, 0, -258, 0, 0, -21, -239, 0, 2, -20, -229, 0, 0, -217, 0, 105, 0, 250, 0, 0, -39, 0, 13, -1, 53, 0, 0, 0, 250, 250, 250, 250, -193, 37, 0, 0, 0, 0, 0, 0, 0, 0, 40, 469, 0, 0, 0, 0, 276, 0, 0, 0, 0, 131, 250, 0, 48, -193, 141, 0, 50, 0, 0, -2, -2, 69, 384, 0, 0, 58, 250, 250, 250, 0, 0, -193, 250, 250, 250, 250, 250, 250, 250, 250, 250, 0, 0, -57, 0, 0, 393, 217, 60, -152, 0, 0, 250, -18, 0, 250, 140, 140, 140, 250, 250, 0, 140, 140,
 140, 52, -2, -2, 69, 69, 69, 250, 0, 0, 0, 250, 0, -193, 250, 426, 174, -207, 469, 528, 554, 460, 96, 276, 276, 469, 250, 97, 469, 0, 0, 469, -28, 0, 0, 250, 0, 0, 0, 469, 0, 0, 0, 0, -195, 276, 250, -124, 250, 0, 0, 469, 250, 469, -113, 469, 276, 0, };
static const YYINT fawkpas_rindex[] = { 0,
0, 152, 0, 0, 152, 0, 0, 0, 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 80, 0, 0, 0, 0, 0, 0, 519, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 561, 617, -11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -37, 0, 0, 810, 858, 883, 0, 0, 0, 922, 952, 966, 785, 652, 710, 17, 43, 71, 112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -48, 992, 814, 113, 0, 0, 0, -47, 0, 0, -45, 0,
 0, -27, 0, 0, 0, 112, 0, 0, 0, -169, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -26, 0, -109, 0, -108, 0, 0, };
static const YYINT fawkpas_gindex[] = { 0,
0, 154, 0, 0, -9, 0, 73, 0, 0, 0, 0, 5, -115, -7, 23, 728, 1206, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, };
#define YYTABLESIZE 1369
static const YYINT fawkpas_table[] = { 77,
60, 120, 77, 77, 77, 77, 77, 77, 21, 77, 18, 40, 3, 20, 6, 152, 83, 85, 9, 149, 77, 77, 77, 77, 77, 74, 77, 128, 61, 74, 74, 74, 74, 74, 87, 74, 10, 88, 14, 85, 161, 89, 12, 91, 86, 13, 15, 74, 74, 74, 74, 168, 74, 69, 17, 77, 63, 69, 69, 69, 69, 69, 94, 69, 153, 83, 85, 48, 144, 145, 48, 62, 127, 158, 159, 69, 69, 69, 69, 70, 69, 74, 28, 70, 70, 70, 70, 70, 87, 70, 38, 88, 64, 85, 83, 71, 84, 72, 86, 29, 29, 70, 70, 70, 70, 95, 70, 71, 88, 69,
 98, 71, 71, 71, 71, 71, 56, 71, 102, 56, 123, 56, 56, 38, 56, 89, 56, 91, 124, 71, 71, 71, 71, 38, 71, 70, 147, 151, 6, 56, 56, 56, 35, 56, 34, 163, 89, 31, 91, 32, 167, 4, 92, 93, 32, 33, 148, 89, 7, 91, 154, 0, 0, 71, 0, 0, 38, 87, 0, 0, 88, 0, 85, 83, 0, 84, 87, 86, 35, 88, 34, 85, 83, 31, 84, 32, 86, 0, 0, 0, 80, 79, 81, 0, 82, 0, 0, 0, 0, 0, 0, 0, 0, 82, 0, 119, 38, 38, 0, 0, 0, 35, 21, 34, 18, 40, 31, 20, 32, 77, 77, 77, 0, 0, 77, 77, 77, 0, 38, 0,
 0, 77, 77, 0, 0, 0, 59, 0, 0, 38, 0, 77, 77, 77, 0, 74, 74, 74, 0, 0, 74, 74, 74, 0, 35, 0, 34, 74, 74, 31, 0, 32, 0, 0, 0, 0, 141, 74, 74, 74, 0, 0, 0, 69, 69, 69, 0, 0, 69, 69, 69, 0, 0, 0, 0, 69, 69, 35, 0, 34, 0, 0, 31, 0, 32, 69, 69, 69, 0, 70, 70, 70, 0, 0, 70, 70, 70, 0, 0, 0, 0, 70, 70, 35, 0, 34, 0, 0, 31, 0, 32, 70, 70, 70, 0, 0, 0, 71, 71, 71, 0, 0, 71, 71, 71, 0, 56, 56, 56, 71, 71, 0, 6, 0, 0, 0, 0, 0, 0, 71, 71, 71, 0, 0, 0, 0, 0, 0, 56, 56,
 56, 0, 0, 0, 19, 20, 0, 0, 0, 21, 22, 0, 23, 0, 0, 0, 24, 25, 26, 27, 28, 29, 30, 0, 0, 0, 33, 73, 74, 75, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 19, 20, 0, 0, 0, 21, 22, 0, 23, 76, 77, 78, 24, 97, 26, 27, 28, 29, 30, 0, 87, 0, 33, 88, 101, 85, 83, 0, 84, 87, 86, 0, 88, 19, 85, 83, 0, 84, 0, 86, 0, 0, 0, 80, 79, 81, 0, 82, 0, 28, 29, 30, 80, 79, 81, 33, 82, 0, 0, 0, 0, 0, 87, 0, 0, 88, 140, 85, 83, 0, 84, 0, 86, 0, 0, 0, 19, 20, 0, 0, 0, 21, 22, 122, 23, 80, 79, 81, 24, 82,
 26, 27, 28, 29, 30, 0, 87, 0, 33, 88, 0, 85, 83, 146, 84, 87, 86, 0, 88, 19, 85, 83, 0, 84, 0, 86, 0, 0, 0, 80, 79, 81, 0, 82, 0, 28, 29, 30, 80, 79, 81, 33, 82, 0, 0, 19, 20, 0, 0, 0, 21, 22, 0, 23, 0, 0, 0, 24, 0, 26, 27, 28, 29, 30, 0, 54, 0, 33, 54, 0, 54, 54, 0, 54, 87, 54, 0, 88, 0, 85, 83, 0, 84, 0, 86, 0, 0, 0, 54, 54, 54, 0, 54, 0, 0, 0, 0, 80, 79, 81, 87, 82, 0, 88, 0, 85, 83, 0, 84, 0, 86, 73, 0, 73, 73, 73, 0, 0, 0, 0, 0, 0, 0, 80, 79, 81, 0, 82, 0, 73,
 73, 73, 73, 0, 73, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 73, 74, 75, 0, 0, 0, 0, 0, 0, 73, 74, 75, 0, 73, 0, 0, 121, 72, 0, 72, 72, 72, 76, 77, 78, 0, 0, 0, 0, 0, 0, 76, 77, 78, 0, 72, 72, 72, 72, 0, 72, 0, 73, 74, 75, 0, 0, 0, 0, 0, 0, 0, 67, 0, 67, 67, 67, 0, 0, 0, 0, 0, 0, 0, 76, 77, 78, 0, 0, 72, 67, 67, 67, 67, 0, 67, 73, 74, 75, 0, 0, 0, 0, 0, 0, 73, 74, 75, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 76, 77, 78, 0, 0, 0, 67, 45, 0, 76, 77, 78,
 68, 0, 68, 68, 68, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 0, 0, 68, 68, 68, 68, 0, 68, 0, 54, 54, 54, 45, 0, 0, 0, 0, 0, 73, 74, 75, 96, 45, 0, 0, 0, 0, 0, 0, 0, 0, 54, 54, 54, 0, 0, 68, 0, 0, 108, 0, 77, 78, 0, 73, 74, 75, 0, 0, 0, 0, 73, 73, 73, 0, 45, 73, 73, 73, 75, 0, 0, 75, 73, 73, 0, 0, 0, 78, 0, 0, 0, 0, 73, 73, 73, 0, 75, 75, 75, 75, 0, 75, 0, 59, 138, 0, 59, 89, 0, 0, 89, 0, 0, 0, 45, 45, 0, 0, 0, 0, 0, 59, 59, 59, 59, 89, 72, 72, 72, 0, 75, 72, 72,
 72, 0, 0, 45, 0, 72, 72, 0, 0, 0, 0, 0, 0, 0, 45, 72, 72, 72, 60, 0, 0, 60, 59, 0, 0, 0, 89, 0, 67, 67, 67, 0, 0, 67, 67, 67, 60, 60, 60, 60, 67, 67, 0, 61, 0, 0, 61, 0, 0, 0, 67, 67, 67, 0, 0, 0, 0, 0, 0, 0, 0, 61, 61, 61, 61, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 58, 68, 68, 68, 0, 0, 68, 68, 68, 0, 61, 0, 0, 68, 68, 58, 58, 58, 58, 0, 0, 0, 0, 68, 68, 68, 0, 63, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 62, 0, 0, 62,
 63, 63, 63, 63, 58, 0, 0, 0, 0, 0, 0, 0, 0, 0, 62, 62, 62, 62, 0, 0, 0, 0, 87, 0, 0, 87, 0, 0, 0, 0, 0, 75, 75, 75, 63, 0, 75, 75, 75, 0, 87, 0, 0, 75, 75, 0, 0, 0, 62, 0, 0, 0, 0, 75, 75, 75, 59, 59, 59, 0, 0, 59, 59, 59, 0, 89, 89, 89, 59, 59, 0, 0, 89, 89, 87, 0, 0, 0, 59, 59, 59, 0, 89, 89, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 60, 60, 60, 0, 0, 60, 60, 60, 0, 0, 0, 0, 60, 60, 0, 0, 0, 0, 0, 0, 0, 0, 60, 60, 60, 61,
 61, 61, 0, 0, 61, 61, 61, 0, 0, 0, 0, 61, 61, 0, 0, 0, 0, 0, 0, 0, 0, 61, 61, 61, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 58, 58, 0, 0, 58, 58, 58, 0, 0, 0, 0, 58, 58, 0, 0, 0, 0, 0, 0, 0, 0, 58, 58, 58, 0, 0, 0, 0, 0, 63, 63, 63, 0, 0, 63, 63, 63, 0, 0, 0, 0, 63, 63, 62, 62, 62, 56, 0, 62, 62, 62, 63, 63, 63, 0, 62, 62, 66, 67, 68, 69, 0, 0, 0, 0, 62, 62, 62, 0, 0, 0, 0, 0, 0, 87, 87, 87, 0, 0, 0, 0, 87, 87, 93, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 103, 104,
 105, 0, 0, 0, 109, 110, 111, 112, 113, 114, 115, 116, 117, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 126, 0, 0, 129, 0, 0, 0, 130, 131, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 132, 0, 0, 0, 136, 0, 0, 139, 0, 142, 0, 0, 0, 0, 0, 0, 0, 0, 0, 150, 0, 0, 0, 0, 0, 0, 0, 0, 132, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 162, 0, 164, 0, 0, 0, 166, };
static const YYINT fawkpas_check[] = { 37,
40, 59, 40, 41, 42, 43, 44, 45, 59, 47, 59, 59, 271, 59, 276, 44, 44, 44, 40, 135, 58, 59, 60, 61, 62, 37, 64, 46, 24, 41, 42, 43, 44, 45, 37, 47, 276, 40, 59, 42, 156, 51, 41, 51, 47, 44, 276, 59, 60, 61, 62, 167, 64, 37, 272, 93, 58, 41, 42, 43, 44, 45, 58, 47, 93, 93, 93, 41, 276, 277, 44, 59, 91, 269, 270, 59, 60, 61, 62, 37, 64, 93, 276, 41, 42, 43, 44, 45, 37, 47, 18, 40, 40, 42, 43, 59, 45, 58, 47, 269, 270, 59, 60, 61, 62, 58, 64, 37, 40, 93,
 61, 41, 42, 43, 44, 45, 37, 47, 61, 40, 61, 42, 43, 51, 45, 135, 47, 135, 281, 59, 60, 61, 62, 61, 64, 93, 41, 41, 59, 60, 61, 62, 38, 64, 40, 270, 156, 43, 156, 45, 264, 0, 41, 41, 264, 264, 134, 167, 5, 167, 146, -1, -1, 93, -1, -1, 94, 37, -1, -1, 40, -1, 42, 43, -1, 45, 37, 47, 38, 40, 40, 42, 43, 43, 45, 45, 47, -1, -1, -1, 60, 61, 62, -1, 64, -1, -1, -1, -1, -1, -1, -1, -1, 64, -1, 263, 134, 135, -1, -1, -1, 38, 263, 40, 263, 263, 43, 263, 45, 257,
 258, 259, -1, -1, 262, 263, 264, -1, 156, -1, -1, 269, 270, -1, -1, -1, 276, -1, -1, 167, -1, 279, 280, 281, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, 38, -1, 40, 269, 270, 43, -1, 45, -1, -1, -1, -1, 93, 279, 280, 281, -1, -1, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, 38, -1, 40, -1, -1, 43, -1, 45, 279, 280, 281, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, 38, -1, 40, -1, -1, 43, -1,
 45, 279, 280, 281, -1, -1, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, 257, 258, 259, 269, 270, -1, 263, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, 260, 261, -1, -1, -1, 265, 266, -1, 268, -1, -1, -1, 272, 273, 274, 275, 276, 277, 278, -1, -1, -1, 282, 257, 258, 259, -1, -1, 262, -1, -1, -1, -1, -1, -1, -1, 260, 261, -1, -1, -1, 265, 266, -1, 268, 279, 280, 281, 272, 273, 274, 275, 276, 277, 278, -1,
 37, -1, 282, 40, 41, 42, 43, -1, 45, 37, 47, -1, 40, 260, 42, 43, -1, 45, -1, 47, -1, -1, -1, 60, 61, 62, -1, 64, -1, 276, 277, 278, 60, 61, 62, 282, 64, -1, -1, -1, -1, -1, 37, -1, -1, 40, 41, 42, 43, -1, 45, -1, 47, -1, -1, -1, 260, 261, -1, -1, -1, 265, 266, 267, 268, 60, 61, 62, 272, 64, 274, 275, 276, 277, 278, -1, 37, -1, 282, 40, -1, 42, 43, 44, 45, 37, 47, -1, 40, 260, 42, 43, -1, 45, -1, 47, -1, -1, -1, 60, 61, 62, -1, 64, -1, 276, 277, 278, 60, 61,
 62, 282, 64, -1, -1, 260, 261, -1, -1, -1, 265, 266, -1, 268, -1, -1, -1, 272, -1, 274, 275, 276, 277, 278, -1, 37, -1, 282, 40, -1, 42, 43, -1, 45, 37, 47, -1, 40, -1, 42, 43, -1, 45, -1, 47, -1, -1, -1, 60, 61, 62, -1, 64, -1, -1, -1, -1, 60, 61, 62, 37, 64, -1, 40, -1, 42, 43, -1, 45, -1, 47, 41, -1, 43, 44, 45, -1, -1, -1, -1, -1, -1, -1, 60, 61, 62, -1, 64, -1, 59, 60, 61, 62, -1, 64, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
 257, 258, 259, -1, -1, -1, -1, -1, -1, 257, 258, 259, -1, 93, -1, -1, 264, 41, -1, 43, 44, 45, 279, 280, 281, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, 59, 60, 61, 62, -1, 64, -1, 257, 258, 259, -1, -1, -1, -1, -1, -1, -1, 41, -1, 43, 44, 45, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, 93, 59, 60, 61, 62, -1, 64, 257, 258, 259, -1, -1, -1, -1, -1, -1, 257, 258, 259, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, 93, 18, -1, 279, 280, 281,
 41, -1, 43, 44, 45, -1, -1, -1, -1, -1, -1, -1, 35, -1, -1, -1, -1, -1, 59, 60, 61, 62, -1, 64, -1, 257, 258, 259, 51, -1, -1, -1, -1, -1, 257, 258, 259, 60, 61, -1, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, 93, -1, -1, 78, -1, 280, 281, -1, 257, 258, 259, -1, -1, -1, -1, 257, 258, 259, -1, 94, 262, 263, 264, 41, -1, -1, 44, 269, 270, -1, -1, -1, 281, -1, -1, -1, -1, 279, 280, 281, -1, 59, 60, 61, 62, -1, 64, -1, 41, 124, -1, 44, 41, -1, -1, 44, -1, -1,
 -1, 134, 135, -1, -1, -1, -1, -1, 59, 60, 61, 62, 59, 257, 258, 259, -1, 93, 262, 263, 264, -1, -1, 156, -1, 269, 270, -1, -1, -1, -1, -1, -1, -1, 167, 279, 280, 281, 41, -1, -1, 44, 93, -1, -1, -1, 93, -1, 257, 258, 259, -1, -1, 262, 263, 264, 59, 60, 61, 62, 269, 270, -1, 41, -1, -1, 44, -1, -1, -1, 279, 280, 281, -1, -1, -1, -1, -1, -1, -1, -1, 59, 60, 61, 62, -1, -1, -1, -1, -1, 93, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 41, -1, -1, 44, 257, 258, 259, -1,
 -1, 262, 263, 264, -1, 93, -1, -1, 269, 270, 59, 60, 61, 62, -1, -1, -1, -1, 279, 280, 281, -1, 41, -1, -1, 44, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 41, -1, -1, 44, 59, 60, 61, 62, 93, -1, -1, -1, -1, -1, -1, -1, -1, -1, 59, 60, 61, 62, -1, -1, -1, -1, 41, -1, -1, 44, -1, -1, -1, -1, -1, 257, 258, 259, 93, -1, 262, 263, 264, -1, 59, -1, -1, 269, 270, -1, -1, -1, 93, -1, -1, -1, -1, 279, 280, 281, 257, 258, 259, -1, -1, 262, 263, 264, -1, 262, 263, 264, 269, 270,
 -1, -1, 269, 270, 93, -1, -1, -1, 279, 280, 281, -1, 279, 280, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, -1, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, -1, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1,
 269, 270, -1, -1, -1, -1, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, -1, -1, 257, 258, 259, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, 257, 258, 259, 20, -1, 262, 263, 264, 279, 280, 281, -1, 269, 270, 31, 32, 33, 34, -1, -1, -1, -1, 279, 280, 281, -1, -1, -1, -1, -1, -1, 262, 263, 264, -1, -1, -1, -1, 269, 270, 57, -1, -1, -1, -1, -1, -1, -1, 279, -1, -1, -1, -1, -1, -1, -1, 73, 74, 75, -1, -1, -1, 79, 80, 81, 82, 83, 84, 85, 86, 87, -1, -1, -1, -1, -1, -1, -1,
 -1, -1, -1, -1, 99, -1, -1, 102, -1, -1, -1, 106, 107, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 118, -1, -1, -1, 122, -1, -1, 125, -1, 127, -1, -1, -1, -1, -1, -1, -1, -1, -1, 137, -1, -1, -1, -1, -1, -1, -1, -1, 146, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 157, -1, 159, -1, -1, -1, 163, };
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 282
#define YYUNDFTOKEN 330
#define YYTRANSLATE(a) ((a) > YYMAXTOKEN ? YYUNDFTOKEN : (a))
int yydebug;
int yynerrs;
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
typedef struct {
    unsigned stacksize;
    YYINT *s_base;
    YYINT *s_mark;
    YYINT *s_last;
    YYSTYPE *l_base;
    YYSTYPE *l_mark;
} YYFPAS_STACKDATA;
static int yyfpas_growstack(YYFPAS_STACKDATA *data)
{
    int i;
    unsigned newsize;
    YYINT *newss;
    YYSTYPE *newvs;
    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return YYENOMEM;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = (int) (data->s_mark - data->s_base);
    newss = (YYINT *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return YYENOMEM;
    data->s_base = newss;
    data->s_mark = newss + i;
    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return YYENOMEM;
    data->l_base = newvs;
    data->l_mark = newvs + i;
    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}
#if YYPURE || defined(YY_NO_LEAKS)
static void yyfpas_freestack(YYFPAS_STACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfpas_freestack(data) 
#endif
#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab
int
YYPARSE_DECL()
{
    int yyerrflag;
    int yychar;
    YYSTYPE yyval;
    YYSTYPE yylval;
    YYFPAS_STACKDATA yystack;
    int yym, yyn, yystate;
    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;
#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif
    if (yystack.s_base == NULL && yyfpas_growstack(&yystack) == YYENOMEM) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;
yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = YYLEX) < 0) yychar = YYEOF;
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        if (yystack.s_mark >= yystack.s_last && yyfpas_growstack(&yystack) == YYENOMEM)
        {
            goto yyoverflow;
        }
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0) --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
    YYERROR_CALL("syntax error");
    goto yyerrlab;
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yystack.s_mark]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
                if (yystack.s_mark >= yystack.s_last && yyfpas_growstack(&yystack) == YYENOMEM)
                {
                    goto yyoverflow;
                }
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == YYEOF) goto yyabort;
        yychar = YYEMPTY;
        goto yyloop;
    }
yyreduce:
    yym = yylen[yyn];
    if (yym)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 1:  { fawkc_addi(ctx, FAWKI_ABORT); fawkc_addcs(ctx, "uninitialized execute"); }
break;
case 2:  { fawkc_addi(ctx, FAWKI_ABORT); fawkc_addcs(ctx, "ran beyond the script"); }
break;
case 6:  { fawkc_addi(ctx, FAWKI_POP); }
break;
case 18:  { fawkc_addi(ctx, FAWKI_SET); fawkc_addi(ctx, FAWKI_PUSH_SYMVAL); fawkc_addi(ctx, FAWKI_POP); }
break;
case 19:  { fawkc_addi(ctx, FAWKI_POP); }
break;
case 21:  { pas_func_ret(); }
break;
case 22:  { fawkc_addi(ctx, FAWKI_POP); }
break;
case 23:  { pas_func_ret(); }
break;
case 26:  {
    fawkc_addi(ctx, FAWKI_FORIN_FIRST);
    fawkc_addi(ctx, FAWKI_JMP);
    fawkc_addnum(ctx, 0);
    PUSH_IP();
   }
break;
case 27:  {
    size_t begin = fawk_pop_num(ctx, 1);
    fawkc_addi(ctx, FAWKI_FORIN_NEXT);
    fawkc_addnum(ctx, begin);
    ctx->code.code[begin-1].data.num = CURR_IP()-2;
   }
break;
case 28:  {
    fawkc_addi(ctx, FAWKI_MAKE_SYMREF);
    fawkc_addsymref(ctx, yystack.l_mark[-2].str, 0, ctx->compiler.funcdef_offs);
    fawkc_addnum(ctx, 0);
   }
break;
case 29:  {
    fawkc_addi(ctx, FAWKI_SET);
    fawkc_addi(ctx, FAWKI_PUSH_SYMVAL);
    fawkc_addi(ctx, FAWKI_POP);
    fawkc_addi(ctx, FAWKI_JMP);
    PUSH_IP();
    fawkc_addnum(ctx, 0);
    PUSH_IP();
   }
break;
case 30:  {
    fawkc_addi(ctx, FAWKI_MAKE_SYMREF);
    fawkc_addsymref(ctx, yystack.l_mark[-6].str, 0, ctx->compiler.funcdef_offs);
    fawkc_addnum(ctx, 0);
    fawkc_addi(ctx, FAWKI_PUSH_SYMVAL);
    fawkc_addi(ctx, FAWKI_SUB);
    fawkc_addi(ctx, FAWKI_PUSH_NUM); fawkc_addnum(ctx, yystack.l_mark[0].num);
    fawkc_addi(ctx, FAWKI_PUSH_REL); fawkc_addnum(ctx, -1);
    fawkc_addi(ctx, FAWKI_PUSH_REL); fawkc_addnum(ctx, -3);
    fawkc_addi(ctx, FAWKI_PUSH_REL); fawkc_addnum(ctx, -2);
    fawkc_addi(ctx, FAWKI_SUB);
    fawkc_addi(ctx, FAWKI_MUL);
    fawkc_addi(ctx, FAWKI_PUSH_NUM); fawkc_addnum(ctx, 0);
    fawkc_addi(ctx, FAWKI_GTEQ);
    fawkc_addi(ctx, FAWKI_POPJZ);
    PUSH_IP();
    fawkc_addnum(ctx, 0);
    fawkc_addi(ctx, FAWKI_MAKE_SYMREF);
    fawkc_addsymref(ctx, yystack.l_mark[-6].str, 0, ctx->compiler.funcdef_offs);
    fawkc_addnum(ctx, 0);
    fawkc_addi(ctx, FAWKI_PUSH_TOPVAR);
    fawkc_addi(ctx, FAWKI_PUSH_REL); fawkc_addnum(ctx, -3);
    fawkc_addi(ctx, FAWKI_ADD); fawkc_addi(ctx, FAWKI_SET);
    fawkc_addi(ctx, FAWKI_POP);
    fawkc_addi(ctx, FAWKI_POP);
    fawkc_addi(ctx, FAWKI_POP);
    fawkc_addi(ctx, FAWKI_JMP);
    PUSH_IP();
    fawkc_addnum(ctx, 0);
    fawkc_addi(ctx, FAWKI_JMP);
    PUSH_IP();
    fawkc_addnum(ctx, 0);
   }
break;
case 31:  {
    size_t jumpin, jback3rd, jskip, jout, rerun;
    jback3rd = fawk_pop_num(ctx, 1);
    jskip = fawk_pop_num(ctx, 1);
    jout = fawk_pop_num(ctx, 1);
    rerun = fawk_pop_num(ctx, 1);
    jumpin = fawk_pop_num(ctx, 1);
    fawkc_addi(ctx, FAWKI_JMP);
    fawkc_addnum(ctx, jskip+1);
    ctx->code.code[jumpin].data.num = jback3rd+1;
    ctx->code.code[jback3rd].data.num = rerun;
    ctx->code.code[jskip].data.num = jback3rd+1;
    ctx->code.code[jout].data.num = CURR_IP();
    fawkc_addi(ctx, FAWKI_POP);
    fawkc_addi(ctx, FAWKI_POP);
   }
break;
case 32:  { yyval.num = +1; }
break;
case 33:  { yyval.num = -1; }
break;
case 36:  { PUSH_IP(); }
break;
case 37:  { fawkc_addi(ctx, FAWKI_POPJZ); PUSH_IP(); fawkc_addnum(ctx, 0); }
break;
case 38:  { loop_pretest_jumpback(); }
break;
case 39:  { PUSH_IP(); }
break;
case 40:  { fawkc_addi(ctx, FAWKI_POPJZ); fawkc_addnum(ctx, fawk_pop_num(ctx, 1));}
break;
case 41:  {
    size_t jmp1 = fawk_pop_num(ctx, 1);
    ctx->code.code[jmp1].data.num = CURR_IP();
   }
break;
case 42:  {
   fawkc_addi(ctx, FAWKI_JMP);
   PUSH_IP(); fawkc_addnum(ctx, 777);
  }
break;
case 43:  {
   size_t jmp_then_post = fawk_pop_num(ctx, 1), jmp_if = fawk_pop_num(ctx, 1);
   ctx->code.code[jmp_then_post].data.num = CURR_IP();
   ctx->code.code[jmp_if].data.num = jmp_then_post+1;
  }
break;
case 44:  { fawkc_addi(ctx, FAWKI_POPJZ); PUSH_IP(); fawkc_addnum(ctx, 777); }
break;
case 45:  { ctx->compiler.numargs = 0; }
break;
case 46:  { fawk_symtab_regfunc(ctx, yystack.l_mark[-5].str, CURR_IP(), ctx->compiler.numargs); ctx->fp = ctx->sp; ctx->parser.curr_func = yystack.l_mark[-5].str; fawkc_addi(ctx, FAWKI_PUSH_NIL); }
break;
case 47:  {
   int n;
   pas_func_ret();
   for(n = 0; n < ctx->compiler.numargs; n++) {
    fawk_cell_t cell;
    fawk_pop(ctx, &cell);
    fawk_cell_free(ctx, &cell);
   }
   ctx->fp = 0;
   free(ctx->parser.curr_func); ctx->parser.curr_func = NULL;
  }
break;
case 49:  { fawk_push_str(ctx, yystack.l_mark[0].str); fawk_free(ctx, yystack.l_mark[0].str); ctx->compiler.numargs++; }
break;
case 50:  { fawk_push_str(ctx, yystack.l_mark[0].str); fawk_free(ctx, yystack.l_mark[0].str); ctx->compiler.numargs++; }
break;
case 51:  { fawkc_addi(ctx, FAWKI_PUSH_NUM); fawkc_addnum(ctx, yystack.l_mark[0].num); }
break;
case 52:  { fawkc_addi(ctx, FAWKI_PUSH_STR); fawkc_adds(ctx, yystack.l_mark[0].str); fawk_free(ctx, yystack.l_mark[0].str); }
break;
case 53:  { fawkc_addi(ctx, FAWKI_PUSH_NIL); }
break;
case 54:  { fawkc_addi(ctx, FAWKI_PUSH_SYMVAL); }
break;
case 58:  { fawkc_addi(ctx, FAWKI_EQ); }
break;
case 59:  { fawkc_addi(ctx, FAWKI_NEQ); }
break;
case 60:  { fawkc_addi(ctx, FAWKI_GTEQ); }
break;
case 61:  { fawkc_addi(ctx, FAWKI_LTEQ); }
break;
case 62:  { fawkc_addi(ctx, FAWKI_GT); }
break;
case 63:  { fawkc_addi(ctx, FAWKI_LT); }
break;
case 64:  { fawkc_addi(ctx, FAWKI_IN); }
break;
case 67:  { fawkc_addi(ctx, FAWKI_ADD); }
break;
case 68:  { fawkc_addi(ctx, FAWKI_SUB); }
break;
case 69:  { fawkc_addi(ctx, FAWKI_MUL); }
break;
case 70:  { fawkc_addi(ctx, FAWKI_DIV); }
break;
case 71:  { fawkc_addi(ctx, FAWKI_MOD); }
break;
case 72:  { fawkc_addi(ctx, FAWKI_NEG); }
break;
case 74:  { fawkc_addi(ctx, FAWKI_NOT); }
break;
case 75:  { fawkc_addi(ctx, FAWKI_CONCAT); }
break;
case 76:  { fawk_push_num(ctx, ctx->compiler.numidx); ctx->compiler.numidx = 0; }
break;
case 77:  {
   fawkc_addi(ctx, FAWKI_MAKE_SYMREF);
   fawkc_addsymref(ctx, yystack.l_mark[-2].str, ctx->compiler.numidx, 0);
   fawkc_addnum(ctx, ctx->compiler.numidx);
   fawk_free(ctx, yystack.l_mark[-2].str);
   ctx->compiler.numidx = fawk_pop_num(ctx, 1);
  }
break;
case 79:  { ctx->compiler.numidx = -1; }
break;
case 80:  { ctx->compiler.numidx++; }
break;
case 81:  { ctx->compiler.numidx++; fawkc_addi(ctx, FAWKI_PUSH_STR); fawkc_adds(ctx, yystack.l_mark[0].str); fawk_free(ctx, yystack.l_mark[0].str); }
break;
case 82:  { ctx->compiler.numidx++; fawkc_addi(ctx, FAWKI_PUSH_STR); fawkc_adds(ctx, yystack.l_mark[0].str); fawk_free(ctx, yystack.l_mark[0].str); }
break;
case 84:  {
   fawkc_addi(ctx, FAWKI_MAKE_SYMREF);
   fawkc_addsymref(ctx, "SUBSEP", ctx->compiler.numidx, 0);
   fawkc_addnum(ctx, 0);
   fawkc_addi(ctx, FAWKI_PUSH_SYMVAL);
   fawkc_addi(ctx, FAWKI_CONCAT);
  }
break;
case 85:  { fawkc_addi(ctx, FAWKI_CONCAT); }
break;
case 86:  { fawkc_addi(ctx, FAWKI_POPJNZ); PUSH_IP(); fawkc_addnum(ctx, 777); }
break;
case 87:  {
   size_t jmp1 = fawk_pop_num(ctx, 1);
   fawkc_addi(ctx, FAWKI_POPJNZ);
   fawkc_addnum(ctx, CURR_IP()+5);
   fawkc_addi(ctx, FAWKI_PUSH_NUM);
   fawkc_addnum(ctx, 0);
   fawkc_addi(ctx, FAWKI_JMP);
   fawkc_addnum(ctx, CURR_IP()+3);
   ctx->code.code[jmp1].data.num = CURR_IP();
   fawkc_addi(ctx, FAWKI_PUSH_NUM);
   fawkc_addnum(ctx, 1);
  }
break;
case 88:  { fawkc_addi(ctx, FAWKI_POPJZ); PUSH_IP(); fawkc_addnum(ctx, 777); }
break;
case 89:  {
   size_t jmp1 = fawk_pop_num(ctx, 1);
   fawkc_addi(ctx, FAWKI_POPJZ);
   fawkc_addnum(ctx, CURR_IP()+5);
   fawkc_addi(ctx, FAWKI_PUSH_NUM);
   fawkc_addnum(ctx, 1);
   fawkc_addi(ctx, FAWKI_JMP);
   fawkc_addnum(ctx, CURR_IP()+3);
   ctx->code.code[jmp1].data.num = CURR_IP();
   fawkc_addi(ctx, FAWKI_PUSH_NUM);
   fawkc_addnum(ctx, 0);
  }
break;
case 90:  { fawk_push_num(ctx, ctx->compiler.numargs); ctx->compiler.numargs = 0; ctx->code.used--; }
break;
case 91:  {
   size_t old_numargs;
   old_numargs = fawk_pop_num(ctx, 1);
   fawkc_addi(ctx, FAWKI_CALL);
   fawkc_addnum(ctx, ctx->compiler.numargs);
   ctx->compiler.numargs = old_numargs;
  }
break;
case 93:  { ctx->compiler.numargs++; }
break;
case 94:  { ctx->compiler.numargs++; }
break;
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            if ((yychar = YYLEX) < 0) yychar = YYEOF;
        }
        if (yychar == YYEOF) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
    if (yystack.s_mark >= yystack.s_last && yyfpas_growstack(&yystack) == YYENOMEM)
    {
        goto yyoverflow;
    }
    *++yystack.s_mark = (YYINT) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;
yyoverflow:
    YYERROR_CALL("yacc stack overflow");
yyabort:
    yyfpas_freestack(&yystack);
    return (1);
yyaccept:
    yyfpas_freestack(&yystack);
    return (0);
}
FAWK_API int fawk_lex_fpas(YYSTYPE *lval, fawk_ctx_t *ctx)
{
 int chr, nchr;
 char tmp[128];
 restart:;
 if (ctx->parser.in_eof) goto handle_eof;
 do { chr = getch(ctx); } while((chr == ' ') || (chr == '\t') || (chr == '\r') || (chr == '\n'));
 ctx->parser.used = 0;
 if (isalpha(chr) || (chr == '_')) {
  append(chr, return -1);
  for(;;) {
   chr = getch(ctx);
   if (!(isalpha(chr)) && !(isdigit(chr)) && (chr != '_') && (chr != '$')) {
    ungetch(ctx, chr);
    break;
   }
   append(chr, return -1);
   if (chr == '$') { append('\0', return -1); goto got_id; }
  }
  append('\0', return -1);
  if (strcmp(ctx->parser.buff, "if") == 0) return PT_IF;
  else if (strcmp(ctx->parser.buff, "then") == 0) return PT_THEN;
  else if (strcmp(ctx->parser.buff, "else") == 0) return PT_ELSE;
  else if (strcmp(ctx->parser.buff, "exit") == 0) return PT_EXIT;
  else if (strcmp(ctx->parser.buff, "for") == 0) return PT_FOR;
  else if (strcmp(ctx->parser.buff, "down") == 0) return PT_DOWN;
  else if (strcmp(ctx->parser.buff, "to") == 0) return PT_TO;
  else if (strcmp(ctx->parser.buff, "while") == 0) return PT_WHILE;
  else if (strcmp(ctx->parser.buff, "do") == 0) return PT_DO;
  else if (strcmp(ctx->parser.buff, "repeat") == 0) return PT_REPEAT;
  else if (strcmp(ctx->parser.buff, "until") == 0) return PT_UNTIL;
  else if (strcmp(ctx->parser.buff, "function") == 0) return PT_FUNCTION;
  else if (strcmp(ctx->parser.buff, "begin") == 0) return PT_BEGIN;
  else if (strcmp(ctx->parser.buff, "end") == 0) return PT_END;
  else if (strcmp(ctx->parser.buff, "and") == 0) return PT_AND;
  else if (strcmp(ctx->parser.buff, "or") == 0) return PT_OR;
  else if (strcmp(ctx->parser.buff, "in") == 0) return PT_IN;
  else if (strcmp(ctx->parser.buff, "not") == 0) return PT_NOT;
  else if ((ctx->parser.curr_func != NULL) && (strcmp(ctx->parser.buff, ctx->parser.curr_func) == 0)) return PT_CURRFUNC;
  else if (strcmp(ctx->parser.buff, "include") == 0) {
   if (ctx->parser.include != NULL) {
    char *fn = ctx->parser.buff;
    fawk_readup(ctx, " \t");
    readtil(ctx, "\""); chr = getch(ctx);
    if (chr == '\"') { ctx->parser.used = 0; readtil(ctx, "\""); append('\0', return -1); getch(ctx); }
    ctx->parser.isp++;
    if (ctx->parser.isp == &ctx->parser.include_stack[FAWK_MAX_INCLUDE_STACK]) {
     sprintf(tmp, "Includes nested too deep\n");
     fawk_error(ctx, tmp);
     return -1;
    }
    ctx->parser.isp->fn = fawk_strdup(ctx, fn); if (ctx->parser.isp->fn == NULL) { return -1; }
    ctx->parser.isp->line = ctx->parser.isp->col = 0;
    if (ctx->parser.include(ctx, ctx->parser.isp, 1, &ctx->parser.isp[-1]) != 0) {
     fawk_free(ctx, ctx->parser.isp->fn); ctx->parser.isp->fn = NULL;
     return -1;
    }
    goto restart;
   }
   sprintf(tmp, "Include not supported by the host application\n");
   fawk_error(ctx, tmp);
   return -1;
  }
  else {
   got_id:; lval->str = fawk_strdup(ctx, ctx->parser.buff);
   return (lval->str == NULL) ? -1 : PT_ID;
  }
 }
 else if (chr == '{') {
  readtil(ctx, "}"); getch(ctx);
  goto restart;
 }
 else if (isdigit(chr)) {
  append(chr, return -1);
  if (chr == '0') {
   nchr = getch(ctx);
   if (nchr == 'x') {
    fawk_readup(ctx, "0123456789abcdefABCDEF");
    lval->num = strtol(ctx->parser.buff, NULL, 16);
    return PT_NUM;
   }
   ungetch(ctx, nchr);
  }
  return read_numeric(ctx, lval, 0, PT_NUM);
 }
 else switch(chr) {
  case '@': case '?': case ':': case ';': case '(': case ')':
  case '[': case '\\': case ']': case ',':
  case '+': case '-': case '*': case '/': case '%': case '=':
   return chr;
  case '.':
   nchr = getch(ctx);
   if (!isdigit(nchr)) {
    ungetch(ctx, nchr);
    return '.';
   }
   else {
    append('.', return -1); append(nchr, return -1);
    return read_numeric(ctx, lval, 1, PT_NUM);
   }
   break;
  case '<':
   nchr = getch(ctx); append(chr, return -1);
   switch(nchr) {
    case '=': return PT_LTEQ;
    case '>': return PT_NEQ;
    default: ungetch(ctx, nchr); return chr;
   }
   break;
  case_op_ch2('>', '=', PT_GTEQ);
  case '\'':
   if (read_strlit(ctx, '\'') == 0) return PT_NIL;
   lval->str = fawk_strdup(ctx, ctx->parser.buff);
   return (lval->str == NULL) ? -1 : PT_STRING;
  case EOF:
   handle_eof:;
   ctx->parser.in_eof = 0;
   fawk_close_include(ctx, ctx->parser.isp);
   if (ctx->parser.isp == &ctx->parser.include_stack[0]) { fawk_free(ctx, ctx->parser.buff); ctx->parser.buff = NULL; ctx->parser.alloced = ctx->parser.used = 0; return EOF; }
   ctx->parser.isp--;
   goto restart;
  default:
   sprintf(tmp, "Invalid character on input: '%c'\n", chr);
   fawk_error(ctx, tmp);
   return -1;
 }
}
